
//----------------------------------------------------------------------------------------------------
//-------------------- Biblioteka obslugi wyswietlacza 128x128 ze sterownikiem ST7735S ---------------
//----------------------------------------------------------------------------------------------------
#include "stm32f10x.h"
#include "ST7735.h"

uint8_t OFFSETX=2, OFFSETY=3; //Definicje offsetow aktywnego obszaru wyswietlacza wzgledem osi X oraz Y


extern volatile uint32_t TIMERUS;

//Inicjalizacja portow obslugujacych wyswietlacz
void LCDgpioinit(void)
{
     	//konfigurowanie portow GPIO
		GPIO_InitTypeDef  GPIO_InitStructure;

	    //Inicjalizacja portow danych
	    RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOC, ENABLE);//wlacz taktowanie portu GPIOC

	    //Ustawienie D0-D7 jako wyjscia (dla wpisywania danych do wyswietlacza)
	  	GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_3 |  GPIO_Pin_4 | GPIO_Pin_5 | GPIO_Pin_6 | GPIO_Pin_7;
	    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
	    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	    GPIO_Init(GPIOC, &GPIO_InitStructure);

	    //Inicjalizacja portow sterujacych
	    RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB, ENABLE);//wlacz taktowanie portu GPIOB
	   // Porty : DC, WR, RD, CS, RESET
	    GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_5 | GPIO_Pin_6 | GPIO_Pin_7 | GPIO_Pin_8 |  GPIO_Pin_9;
	    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
	    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	    GPIO_Init(GPIOB, &GPIO_InitStructure);

	    GPIOB->BSRR = GPIO_Pin_5 | GPIO_Pin_6 | GPIO_Pin_7 | GPIO_Pin_8 |  GPIO_Pin_9;  //ustawienie portow w stan wysoki
}

//Wysklanie komendy sterujacej
void WriteCommand(uint8_t command)
{
	uint16_t temp;

	Clr_DC;  //Command

	Set_RD;  //wylaczenie odczytywania danych

	temp=dataGPIO->ODR;
	temp=temp & 0xff00;  //wyczyszczenie lini danych
	dataGPIO->ODR = temp | command;  //Wylasnie na liniie komendy z maskowaniem najstarszych bitow
	Clr_WR;                          //zatrzasniecie danych linia WR
	asm("NOP");
	asm("NOP");
	Set_WR;

}

//Wpisanie danych po wyslaniu komendy
void WriteData(uint8_t data)
{
	uint16_t temp;

	Set_DC;  //Data

	Set_RD;  //wylaczenie odczytywania danych

	temp=dataGPIO->ODR;
	temp=temp & 0xff00;  //wyczyszczenie lini danych
	dataGPIO->ODR = temp | data;  //Wylasnie na liniie komendy z maskowaniem najstarszych bitow

	Clr_WR;
	asm("NOP");
	asm("NOP");
	Set_WR;

}

//Odczytanie danych po wyslaniu komendy
uint8_t ReadData(void)
{
	uint16_t temp;

	//konfigurowanie portow GPIO
			  GPIO_InitTypeDef  GPIO_InitStructure;

	  //Ustawienie D0-D7 jako wejscia (dla odbierania danych z wyswietlacza)
		  	GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_3 |  GPIO_Pin_4 | GPIO_Pin_5 | GPIO_Pin_6 | GPIO_Pin_7;
		    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IPD;
		    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
		    GPIO_Init(GPIOC, &GPIO_InitStructure);

	Set_DC;  //Data

	Set_WR;  //Wylaczenie wpisywania danych

	Clr_RD;
	readdelay();
	temp=dataGPIO->IDR;  //Pusty bajt (Dummy)
	readdelay();
	Set_RD;

	Clr_RD;
	readdelay();
	temp=dataGPIO->IDR; //Odczytanie prawidlowego bajtu
	readdelay();
	Set_RD;

	  //Ustawienie D0-D7 jako wyjscia (dla wpisywania danych do wyswietlacza)
		  	GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_3 |  GPIO_Pin_4 | GPIO_Pin_5 | GPIO_Pin_6 | GPIO_Pin_7;
		    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
		    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
		    GPIO_Init(GPIOC, &GPIO_InitStructure);


	return (uint8_t)temp;
}

//Odczyt wielu bajtow z bufora RAM kontrolera LCD
void ReadManyData(uint8_t *buffor, uint32_t *k, uint8_t x1, uint8_t y1, uint8_t x2, uint8_t y2)
{
	uint8_t *s;
	uint8_t red, green, blue;
	uint16_t tempcolor;
	uint32_t i=0;
	uint32_t maksbuf, deltax, deltay;

	             //konfigurowanie portow GPIO
				GPIO_InitTypeDef  GPIO_InitStructure;



			    s=buffor;
			    deltax=x2-x1+1;
			    deltay=y2-y1+1;
			    maksbuf=deltax*deltay;

			    *k=deltax;
			    k++;
			    *k=deltay;
			    k++;
			    *k=maksbuf;


				Clr_CS;
				readdelay();
				WriteCommand(ST7735_COLMOD);  //ustawienie glebi kolorow na 666 przed odczytem
				WriteData(0x66);
				readdelay();
				Set_CS;

			    SetActiveArea(x1, y1, x2, y2);

			    Clr_CS;
			    readdelay();
			    WriteCommand(ST7735_RAMRD);
			    readdelay();


			             //Ustawienie D0-D7 jako wejscia (dla odbierania danych z wyswietlacza)
			   			GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_3 |  GPIO_Pin_4 | GPIO_Pin_5 | GPIO_Pin_6 | GPIO_Pin_7;
			   			GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IPD;
			   			GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
			   		    GPIO_Init(GPIOC, &GPIO_InitStructure);
			   		    readdelay();

			   			Set_DC;  //Data
			   			Set_WR;  //Wylaczenie wpisywania danych
			   			readdelay();

			   			Clr_RD;
			   			readdelay();
			   		    blue=dataGPIO->IDR;  // odczytanie bajtu dummy
			   		    readdelay();   //---
			   			Set_RD;
			   			readdelay();


			    for(i=0; i<maksbuf; i++)
			    	{


			    	readdelay();
			        Clr_RD;
			        readdelay();
			       	red=dataGPIO->IDR;
			       	readdelay();
			       	Set_RD;
			       	readdelay();

			   	    Clr_RD;
			   	    readdelay();
			   		green=dataGPIO->IDR;
			   		readdelay();
			   		Set_RD;
			   		readdelay();

			   		Clr_RD;
			   	    readdelay();
			   		blue=dataGPIO->IDR;
			   		readdelay();
			   		Set_RD;
			   		readdelay();

			   		red=red>>3;
			   		green=green>>2;
			   		blue=blue>>3;

			   		tempcolor=(red<<11) | (green<<5) | blue;
			   			     			//*s=(uint8_t)tempcolor;
			   			     		*s=(tempcolor>>8);
			   			     			   	s++;
			   			     			*s=(uint8_t)tempcolor;
			   			     			//*s=(tempcolor>>8);
			   			     			   	s++;

			    	}

			    readdelay();
			    Set_CS;

			   	//Ustawienie D0-D7 jako wyjscia (dla wpisywania danych do wyswietlacza)
			   	GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_3 |  GPIO_Pin_4 | GPIO_Pin_5 | GPIO_Pin_6 | GPIO_Pin_7;
			   	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
			   	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
			   	GPIO_Init(GPIOC, &GPIO_InitStructure);
			   	readdelay();

				Clr_CS;
				readdelay();
				WriteCommand(ST7735_COLMOD);  //ustawienie glebi kolorow na 565
				WriteData(0x55);
				readdelay();
				Set_CS;


}

//narysowanie danego obrazka ktory zostal odczytany z wyswietlacza i zapisany w talibcy ts
void putfrombufor(uint8_t *ts, uint32_t *k, uint16_t x, uint16_t y)
{
uint8_t *s;
s=ts;

uint32_t i=0;
uint32_t temp1, temp2, temp3;
temp1=*k;   //szerokosc
temp1=temp1-1;
k++;
temp2=*k;   //wysokosc
temp2=temp2-1;
k++;
temp3=*k;   //obliczona wartosc elementow bufora

SetActiveArea(x, y, x+temp1, y+temp2);
Clr_CS;
WriteCommand(ST7735_RAMWR);


	for(i=0; i<temp3; i++)
	{

		WriteData(*s);
		s++;
		WriteData(*s);
		s++;

	}
Set_CS;
}

//Reset sprzetowy oraz sprogramowy
void Reset_SH(void)
{
	//Reset sprzetowy
	Clr_RST;
	ST7735delay(10);                 //odczekanie 10ms
	Set_RST;
	ST7735delay(150);                //odczekanie 150ms

	Clr_CS;
	WriteCommand(ST7735_SWRESET);
	Set_CS;

}

void readdelay(void)
{
	uint32_t temp;

	for(temp=0; temp<2; temp++)
	{
	asm("NOP");// asm("NOP"); //asm("NOP"); asm("NOP"); asm("NOP"); asm("NOP"); asm("NOP"); asm("NOP");
	}

}

//Funkcja delay
void ST7735delay(uint16_t ms)
{
	TIMERUS=ms*10;
	while(TIMERUS)
	{
	}
}

//Inicjalizacja wyswietlacza
void LCDinit(void)
{

	LCDgpioinit(); //inizjalizacja portow
	Reset_SH();    //Reset sprzetowy oraz programowy

	//Po resecie wszystkie ustawienia przyjmujace wartosc domysln s ustawione dobrze.
	//Nalezy wlaczyc glebie 565, wybudzic wyswietlacz oraz zalaczyc

	Clr_CS;
	WriteCommand(ST7735_COLMOD);  //ustawienie glebi kolorow na 565
	WriteData(0x55);
	Set_CS;

    MemoryControl(1, 1, 0, 0, 1, 0);  //ustawienie poczatku ukladu wspolrzednych dla wyswietlacza (lewy gorny rog, orag odczyt kolorow jako BGR)

    Clr_CS;
	WriteCommand(ST7735_FRMCTR1); // Kontrola czesostliwosci odswiezania
	WriteData(0x00);          // ustawienie jak najszybszego odswiezania wyswietlacza
	WriteData(0x6);          // 6 lini front porch  - standardowo jest 0x3c
	WriteData(0x3);          // 3 linie backporch  - standardowo jest 0x3c
	Set_CS;
	ST7735delay(10);

	Clr_CS;
	WriteCommand(ST7735_SLPOUT);  //Wybudzenie
	Set_CS;
	ST7735delay(150);             //odczekanie 150ms

	Clr_CS;
	WriteCommand(ST7735_DISPON);  //Zalaczenie wyswietlacza
	Set_CS;

}

//Ustawienie aktywnego obszaru na wyswietlaczu
void SetActiveArea(uint16_t x1, uint16_t y1, uint16_t x2, uint16_t y2)
{

	uint16_t tx1, tx2, ty1, ty2;
	uint8_t start1, start2, end1, end2;

	tx1=x1+OFFSETX;
	tx2=x2+OFFSETX;
	ty1=y1+OFFSETY;
	ty2=y2+OFFSETY;

	start1=ty1>>8;
	start2=(uint8_t) ty1 & 0xff;
	end1=ty2>>8;
	end2=(uint8_t) ty2 & 0xff;

	Clr_CS;
	WriteCommand(ST7735_RASET);
	WriteData(start1);
	WriteData(start2);
	WriteData(end1);
	WriteData(end2);
	Set_CS;

	start1=tx1>>8;
	start2=(uint8_t) tx1 & 0xff;
	end1=tx2>>8;
	end2=(uint8_t) tx2 & 0xff;


	Clr_CS;
	WriteCommand(ST7735_CASET);
	WriteData(start1);
	WriteData(start2);
	WriteData(end1);
	WriteData(end2);
	Set_CS;
}



//Narysowanie pixela na wyswietlaczu
void PutPixel(uint16_t x, uint16_t y, uint16_t color)
{
	SetActiveArea(x, y, x, y);

	Clr_CS;
	WriteCommand(ST7735_RAMWR);
	WriteData((uint8_t)(color>>8));
	WriteData((uint8_t)(color));

	Set_CS;
}

//Funkcja czyszczaca caly wyswietlacz danym kolorem
void cleanlcd(uint16_t color)
{
	full_rect( 0, 0, 127, 127, color);
}


//Rysowanie pelnego kwadratu
void full_rect( int X1, int Y1, int X2, int Y2, uint16_t color)
{
	uint16_t temp1, temp2;
	uint32_t tempmul;
	uint32_t k;

	temp1=X2-X1;
	temp2=Y2-Y1;

	tempmul=(temp1+1)*(temp2+1);


	SetActiveArea(X1,Y1,X2,Y2);
	Clr_CS;
	WriteCommand(ST7735_RAMWR);


	for(k=0; k<tempmul; k++)
	{
		WriteData((uint8_t)(color>>8));
		WriteData((uint8_t)(color));
	}

	Set_CS;
}

//Ustawienie ustawien w rejestrze kontrolnym
void MemoryControl(uint8_t my, uint8_t mx, uint8_t mv, uint8_t ml, uint8_t rgb, uint8_t mh)
{
	uint8_t temp=0;

	temp=(my<<7) | (mx<<6) | (mv<<5) | (ml<<4) | (rgb<<3)  | (mh<<2);
	Clr_CS;
	WriteCommand(ST7735_MADCTL);
	WriteData(temp);
	Set_CS;
}

//Funkcja ustawiajaca tryb partial mode (wyswietlanie tylko czesci na wyswietlaczu)
void PartialMode(uint8_t start, uint8_t end)
{
	    Clr_CS;
		WriteCommand(ST7735_PTLON);  //ustawienie trybu Partial Mode
		Set_CS;

		Clr_CS;
		WriteCommand(ST7735_PTLAR);  //ustawienie trybu Partial Mode
		WriteData(0x00);
		WriteData(start);
		WriteData(0x00);
		WriteData(end);
		Set_CS;
}

//Zalaczenie NORMAL MODE
void NormalMode(void)
{
	        Clr_CS;
	 		WriteCommand(ST7735_NORON);  //ustawienie trybu Partial Mode
			Set_CS;
}

//Rysowanie lini
void tft_line(int X1, int Y1,int X2,int Y2,int Color)
{
	int CurrentX, CurrentY, Xinc, Yinc,
		Dx, Dy, TwoDx, TwoDy,
		TwoDxAccumulatedError, TwoDyAccumulatedError;

	Dx = (X2-X1);
	Dy = (Y2-Y1);

	TwoDx = Dx + Dx;
	TwoDy = Dy + Dy;

	CurrentX = X1;
	CurrentY = Y1;

	Xinc = 1;
	Yinc = 1;

	if(Dx < 0) {

		Xinc = -1;
		Dx = -Dx;
		TwoDx = -TwoDx;
	}

	if (Dy < 0) {
		Yinc = -1;
		Dy = -Dy;
		TwoDy = -TwoDy;
	}

	PutPixel( X1, Y1, Color);


	if ((Dx != 0) || (Dy != 0)) {

		if (Dy <= Dx) {
			TwoDxAccumulatedError = 0;
			do {
			    CurrentX += Xinc;
			    TwoDxAccumulatedError += TwoDy;
			    if(TwoDxAccumulatedError > Dx) {
			        CurrentY += Yinc;
			        TwoDxAccumulatedError -= TwoDx;
			    }
			    PutPixel( CurrentX, CurrentY, Color);

			  } while (CurrentX != X2);
		  } else {
			  TwoDyAccumulatedError = 0;
			  do {
			      CurrentY += Yinc;
			      TwoDyAccumulatedError += TwoDx;
			      if(TwoDyAccumulatedError>Dy) {
				      CurrentX += Xinc;
				      TwoDyAccumulatedError -= TwoDy;
			      }
			      PutPixel( CurrentX, CurrentY, Color);

			  } while (CurrentY != Y2);
		  }
	}
}

//Funkcja rysujaca narysowana grafike w monohromatyczna w pikselach
//alfa oznacza czy nalezy wypelnic nieuzyte tlo kolore lub tez nie
uint8_t putmonograph(uint16_t x, uint16_t y, uint16_t color, uint16_t bkcolor, uint16_t width, uint16_t height,const uint8_t *s, uint8_t alpha)
{
	uint8_t tempi, tempk, wier, dtemp=0, fault=0;
	unsigned char wartosc;
	const uint8_t *p;

	//jezeli wysokosc i szerokosc nie jest podzielna przez 8 to zwroc blad
	if(height%8) fault= 1;
	if(width%8) fault= 1;

	wier=width/8;

	for(tempk=0; tempk<height; tempk++)
	{
	for(tempi=0; tempi<wier; tempi++)
	{
		p=s+(tempk*wier)+tempi;
		wartosc=*p;
		for(dtemp=0; dtemp<8; dtemp++)
		{

			if(wartosc & (1<<(7-dtemp)))  PutPixel(x+(tempi*8)+dtemp, y+tempk, color);
		    else if(!alpha)  PutPixel(x+(tempi*8)+dtemp, y+tempk, bkcolor);
		}

	}
	}

	return fault;
}

//rysowanie grubej lini
void tft_linebold(int X1, int Y1,int X2,int Y2,int Color)
{
	int CurrentX, CurrentY, Xinc, Yinc,
		Dx, Dy, TwoDx, TwoDy,
		TwoDxAccumulatedError, TwoDyAccumulatedError;
	uint8_t kk;

	Dx = (X2-X1);
	Dy = (Y2-Y1);

	TwoDx = Dx + Dx;
	TwoDy = Dy + Dy;

	CurrentX = X1;
	CurrentY = Y1;

	Xinc = 1;
	Yinc = 1;

	if(Dx < 0) {

		Xinc = -1;
		Dx = -Dx;
		TwoDx = -TwoDx;
	}

	if (Dy < 0) {
		Yinc = -1;
		Dy = -Dy;
		TwoDy = -TwoDy;
	}


	SetActiveArea(X1-1,Y1-1,X2+1,Y2+1);
	Clr_CS;
	WriteCommand(ST7735_RAMWR);

		for(kk=0; kk<=9; kk++)
		{
		    WriteData(Color>>8);
		    WriteData((uint8_t)Color);
		}
	Set_CS;



	if ((Dx != 0) || (Dy != 0)) {

		if (Dy <= Dx) {
			TwoDxAccumulatedError = 0;
			do {
			    CurrentX += Xinc;
			    TwoDxAccumulatedError += TwoDy;
			    if(TwoDxAccumulatedError > Dx) {
			        CurrentY += Yinc;
			        TwoDxAccumulatedError -= TwoDx;
			    }


			    SetActiveArea(CurrentX-1,CurrentY-1,CurrentX+1,CurrentY+1);
			    Clr_CS;
			    WriteCommand(ST7735_RAMWR);

							for(kk=0; kk<=9; kk++)
							{
								 WriteData(Color>>8);
								 WriteData((uint8_t)Color);
							}
						Set_CS;

			  } while (CurrentX != X2);
		  } else {
			  TwoDyAccumulatedError = 0;
			  do {
			      CurrentY += Yinc;
			      TwoDyAccumulatedError += TwoDx;
			      if(TwoDyAccumulatedError>Dy) {
				      CurrentX += Xinc;
				      TwoDyAccumulatedError -= TwoDy;
			      }
			      SetActiveArea(CurrentX-1,CurrentY-1,CurrentX+1,CurrentY+1);
			      Clr_CS;
			      WriteCommand(ST7735_RAMWR);

			      							for(kk=0; kk<=9; kk++)
			      							{
			      								 WriteData(Color>>8);
			      								 WriteData((uint8_t)Color);
			      							}
			      						Set_CS;

			  } while (CurrentY != Y2);
		  }
	}
}

//Szybkie wstawianie grafiki na wyswietlacz
void putfastpicture(u16 x, u16 y, u16 width, u16 height, unsigned char const *grafika)
{
		u16 i, j ;
		uint8_t k, t;
		unsigned char const *s;

		s=grafika;

		SetActiveArea(x, y, x+width-1, y+height-1);
		 Clr_CS;
	     WriteCommand(ST7735_RAMWR);

		for(j=0; j<height; j++)
		{
				for(i=0; i<width; i++)
				{
					k=(*s);
					s++;
					t=*s;
					s++;
		            WriteData(t);
		            WriteData(k);
				}
		}

		Set_CS;
}


//Funkcja rysujaca kwadrat przezroczystosci na danym obszarze X1-x2  ; y2-y1, o kolore color
void full_rectalpha( int X1, int Y1, int X2, int Y2, uint16_t color)
{
	uint16_t temp1, temp2;

	uint32_t k,d;

	temp1=X2-X1;
	temp2=Y2-Y1;
	temp1=temp1+1;
	temp2=temp2+1;



	  for(d=0; d<temp2; d++)
	{
		  for(k=0; k<temp1; k++)
		  {

			  if(d%2)
			  {
				  if(k%2)
				  {
					PutPixel(X1+k, Y1+d, color);
				  }
			  }
			  else
			  {
				  if(!(k%2))
				  {
					  PutPixel(X1+k, Y1+d, color);
				  }
			  }

		  }
	}
}


//Funkcja rysujacy pelny prostokat
void full_rect3( uint8_t X1, uint8_t Y1, uint8_t X2, uint8_t Y2, uint16_t color)
{
	uint8_t temp1, temp2;
	uint16_t tempmul;
	uint16_t k;

	temp1=X2-X1;
	temp2=Y2-Y1;

	tempmul=(temp1+1)*(temp2+1);


	SetActiveArea(X1, Y1, X2, Y2);
	 Clr_CS;
     WriteCommand(ST7735_RAMWR);

	for(k=0; k<=tempmul; k++)
	{
		WriteData((uint8_t)(color>>8));
		WriteData((uint8_t)(color));
	}
	Set_CS;

}


//Szybkie wstawianie grafiki ta na wyswietlacz 128x128px
void putbackground(u8 x, u8 y, u8 width, u8 height, unsigned char const *grafika)
{
		u16 i, j ;
		uint8_t k, t;
		unsigned char const *s;



		 SetActiveArea(x, y, x+width-1, y+height-1);
		 Clr_CS;
	         WriteCommand(ST7735_RAMWR);

		for(j=0; j<height; j++)
		{
			s=(grafika+(128*y*2)+(128*j*2)+(2*x));
				for(i=0; i<width; i++)
				{
					k=(*s);
					s++;
					t=*s;
					s++;
		            WriteData(t);
		            WriteData(k);
				}
		}

		Set_CS;
}


//rysowanie lini z uzyciem tla
void tft_linewallpaper(int X1, int Y1,int X2,int Y2, unsigned char const *grafika)
{
	int CurrentX, CurrentY, Xinc, Yinc,
		Dx, Dy, TwoDx, TwoDy,
		TwoDxAccumulatedError, TwoDyAccumulatedError;


	Dx = (X2-X1);
	Dy = (Y2-Y1);

	TwoDx = Dx + Dx;
	TwoDy = Dy + Dy;

	CurrentX = X1;
	CurrentY = Y1;

	Xinc = 1;
	Yinc = 1;

	if(Dx < 0) {

		Xinc = -1;
		Dx = -Dx;
		TwoDx = -TwoDx;
	}

	if (Dy < 0) {
		Yinc = -1;
		Dy = -Dy;
		TwoDy = -TwoDy;
	}

	putbackground(X1, Y1, 1, 1, grafika);

	if ((Dx != 0) || (Dy != 0)) {

		if (Dy <= Dx) {
			TwoDxAccumulatedError = 0;
			do {
			    CurrentX += Xinc;
			    TwoDxAccumulatedError += TwoDy;
			    if(TwoDxAccumulatedError > Dx) {
			        CurrentY += Yinc;
			        TwoDxAccumulatedError -= TwoDx;
			    }

				putbackground(CurrentX-1, CurrentY-1, 3, 3, grafika);

			  } while (CurrentX != X2);
		  } else {
			  TwoDyAccumulatedError = 0;
			  do {
			      CurrentY += Yinc;
			      TwoDyAccumulatedError += TwoDx;
			      if(TwoDyAccumulatedError>Dy) {
				      CurrentX += Xinc;
				      TwoDyAccumulatedError -= TwoDy;
			      }

			      putbackground(CurrentX-1, CurrentY-1, 3, 3, grafika);

			  } while (CurrentY != Y2);
		  }
	}
}

