//----------------------------------------------------------------------------------------------------
//-------------------- Biblioteka obslugi wyswietlacza 128x128 ze sterownikiem ST7735S ---------------
//----------------------------------------------------------------------------------------------------



#define dataGPIO  GPIOC    //Definicja portu do ktorego jest podlaczona linia danych

//Definicje poszczegolnych lini sterujacych
#define Set_WR   GPIOB->BSRR = GPIO_Pin_5
#define Clr_WR   GPIOB->BRR = GPIO_Pin_5
#define Set_RD   GPIOB->BSRR = GPIO_Pin_6
#define Clr_RD   GPIOB->BRR = GPIO_Pin_6
#define Set_CS   GPIOB->BSRR = GPIO_Pin_7
#define Clr_CS   GPIOB->BRR = GPIO_Pin_7
#define Set_DC   GPIOB->BSRR = GPIO_Pin_8
#define Clr_DC   GPIOB->BRR = GPIO_Pin_8
#define Set_RST  GPIOB->BSRR = GPIO_Pin_9
#define Clr_RST  GPIOB->BRR = GPIO_Pin_9

//Definicje kolorow dla glebi 565=65k
#define Yellow1 0xEFC0
#define Yellow2 0xCEA0
#define Yellow3 0xF785
#define Orange1 0xFB42
#define Orange2 0xFC26
#define Orange3 0xFAE0
#define Red1    0xF800
#define Red2    0xE000
#define Red3    0xB800
#define Green1  0x4DC0
#define Green2  0x1521
#define Green3  0x0B82
#define Gray1   0x6B4D
#define Gray2   0x8C71
#define Gray3   0xAD54
#define Blue1   0x085D
#define Blue2   0x3A1E
#define Blue3   0x16BD
#define Blue4   0x1334
#define Pink1   0xF9DD
#define Pink2   0xC037
#define Pink3   0x8830
#define Black1  0x0000
#define Black2  0x3186
#define Black3  0x4A69
#define White   0xFFFF
#define alphagray1  0xCE18
#define alphagray2  0xBD96
#define alphared1   0xFC30


//Definicje komend
#define ST7735_NOP           0x00    //NOP
#define ST7735_SWRESET       0x01    //Reset programowy
#define ST7735_RDDID         0x04    //Odczyt ID sterownika
#define ST7735_RDDST         0x09    //Wyslanie zadania odczytu 5 bajtow statusowych wyswietlacza Read Display Status
#define ST7735_RDDPM         0x0A    //Read display Power mode - wyslanie komendy odczytu 2 bajtow z danymi stanu w ktorym znajduje sie sterownik
#define ST7735_RDDMADCTL     0x0B    //Odczyt rejestru MADCTL (komenda zwraca 2 bajty) dane: MX, MY, MV, ML, RGB
#define ST7735_RDDCOLMOD     0x0C    //Odczytanie aktualnie uzywanego formatu 565, 666, 444 (zwraca 2 bajty)
#define ST7735_RDDIM         0x0D    //Read display image mode
#define ST7735_RDDSM         0x0E    //Read display signal mode
#define ST7735_RDDSDR        0x0F    //Read display self diagnostic mode
#define ST7735_SLPIN         0x10    //Przejscie do trybu uspienia SLEEP IN
#define ST7735_SLPOUT        0x11    //Wybudzenie sterownika SLEEP OUT
#define ST7735_PTLON         0x12    //Partial mode ON - zalaczenie obslugi tylko czesci wyswietlacza  (po resecie nieaktywny)
#define ST7735_NORON         0x13    //Normaln mode ON - zalaczenie obslugi calego wyswietlacza (po resecie aktywny)
#define ST7735_INVOFF        0x20    //Display inversion off - wylaczenie inwersji (po resecie wylaczona inwersja)
#define ST7735_INVON         0x21    //Zalaczenie inwersji (po resecie nieaktywna)
#define ST7735_GAMSET        0x26    //Gamm set - ustawienie krzywej gamma
#define ST7735_DISPOFF       0x28    //Display off - wylaczenie wyswietlacza
#define ST7735_DISPON        0x29    //Zalaczenie wyswietlacza
#define ST7735_CASET         0x2A    //Wyslanie komendy zaznaczajacej aktywny obszar w kolumnach (4bajty -> 1Bajt MSB start adres 2Bajt LSB start adres, 3Bajt MSB end adres, 4Bajt LSB end adres)
#define ST7735_RASET         0x2B    //Row adres - ustawienie obszaru w wierszach. 4 bajty. Pierwsze dwa bajty s startem.
#define ST7735_RAMWR         0x2C    //Wyslanie komendy aktywujacej wpisywanie danych do pamieci RAM sterownika
#define ST7735_RGBSET        0x2D    //Ustawienie kolorow dla 4k, 65k, 262k
#define ST7735_RAMRD         0x2E    //Wyslanie komendy wymuszajacej odczyt danych z pamieci RAM (z zaznaczonego obszaru CASET, RASET)
#define ST7735_PTLAR         0x30    //Wyslanie komendy po ktorej nastepuje zaznaczenia obszaru PARTIAL (w przypadku wylaczenia czesci wyswietlacza PARTIAL ON)
#define ST7735_SCRLAR        0x33    //Scroll adres set
#define ST7735_TEOFF         0x34    //Tearing effect off (tearing effect wylaczony po resecie)
#define ST7735_TEON          0x35    //Zalaczenie tearing effect
#define ST7735_MADCTL        0x36    //Memory data adres control (po wyslaniu komedny, nalezy wyslac jeden bajt z parametrami) Po resecie wszystkie bity MY,MV,MX, RGB, MH wynosza 0
#define ST7735_VSCSAD        0x37    //Vertical scroll start adress
#define ST7735_IDMOFF        0x38    //Iddle mode off. Po resecie Iddle mode wylaczone. W tym stanie wyswietlacz moze pracowac w trybie 444, 565, 666 oraz pracuje z normalna czestotliwoscia odswiezania.
#define ST7735_IDMON         0x39    //Iddle mode on
#define ST7735_COLMOD        0x3A    //Color MODE. Po wyslaniu komendy nalezy wyslac glebie kolorow 565, 444, 666 (tylko w trybie normal mode ktory jest stanem po resecie). 3 najmlodsze bity
#define ST7735_RDID1         0xDA    //Read ID value 1
#define ST7735_RDID2         0xDB    //Read ID value 2
#define ST7735_RDID3         0xDC    //Read ID value 3
#define ST7735_FRMCTR1       0xB1    //Ustawienie czestotliwosci odswiezania. Po resecie ma wstepnie ustawiona wartosc w zaleznosci od zwartych nozek sterownika (3 bajty danych). W trybie NORMAL MODE
#define ST7735_FRMCTR2       0xB2    //W trybie Iddle mode 8 color
#define ST7735_FRMCTR3       0xB3    //W trybie Partial mode full color
#define ST7735_INVCTR        0xB4    //Invesion control
#define ST7735_PWCTR1        0xC0    //Power control
#define ST7735_PWCTR2        0xC1
#define ST7735_PWCTR3        0xC2
#define ST7735_PWCTR4        0xC3
#define ST7735_PWCTR5        0xC4
#define ST7735_VMCTR1        0xC5    //VCOM control 1
#define ST7735_VMOFCTR       0xC7    //VCOM offset control
#define ST7735_WRID2         0xD1    //Write ID2 value
#define ST7735_WRID3         0xD2    //Write ID3 value
#define ST7735_NVFCTR1       0xD9    //NVM control status
#define ST7735_NVFCTR2       0xDE    //NVM read command
#define ST7735_NVFCTR3       0xDF    //NVM write command
#define ST7735_GMCTRN1       0xE1    //Polaryzacja gamma


//Sterownik ST7735 posiada pamiec na 132x162px dlatego w wyswietlaczu musi byc wybrana opcja GM[1:0]="11" wtedy aktywny obszar ram bedzie wynosci 128x160px i bedzie zgodny z wyswietlaczem
//Odpowiednie ustawienie GM ustawiane jest za pomoca pinow wyjsciowych sterownika. Przy kupnie wyswietlacza ze sterownikiem Piny juz sa odpowiednio ustawione.
//Czestotliwosc odsiwezania po resecie zalezy od wyboru GM. Dla GM=11 wynosi. fosc=850kHz/((5x2+40)x(160+60+60))=850kH/14k=60Hz. Czestotliwosc odswiezania wynosi 60Hz.



void LCDgpioinit(void);
void WriteCommand(uint8_t command);
void WriteData(uint8_t data);
uint8_t ReadData(void);
void ST7735delay(uint16_t ms);
void Reset_SH(void);
void LCDinit(void);
void SetActiveArea(uint16_t x1, uint16_t y1, uint16_t x2, uint16_t y2);
void PutPixel(uint16_t x, uint16_t y, uint16_t color);
void full_rect( int X1, int Y1, int X2, int Y2, uint16_t color);
void tft_line(int X1, int Y1,int X2,int Y2,int Color);
void cleanlcd(uint16_t color);
void MemoryControl(uint8_t my, uint8_t mx, uint8_t mv, uint8_t ml, uint8_t rgb, uint8_t mh);
void PartialMode(uint8_t start, uint8_t end);
void NormalMode(void);
uint8_t putmonograph(uint16_t x, uint16_t y, uint16_t color, uint16_t bkcolor, uint16_t width, uint16_t height,const uint8_t *s, uint8_t alpha);
void tft_linebold(int X1, int Y1,int X2,int Y2,int Color);
void putfastpicture(u16 x, u16 y, u16 width, u16 height, unsigned char const *grafika);
void full_rectalpha( int X1, int Y1, int X2, int Y2, uint16_t color);
void putfrombufor(uint8_t *ts, uint32_t *k, uint16_t x, uint16_t y);
void ReadManyData(uint8_t *buffor, uint32_t *k, uint8_t x1, uint8_t y1, uint8_t x2, uint8_t y2);
void readdelay(void);
void full_rect3( uint8_t X1, uint8_t Y1, uint8_t X2, uint8_t Y2, uint16_t color);
void putbackground(u8 x, u8 y, u8 width, u8 height, unsigned char const *grafika);
void tft_linewallpaper(int X1, int Y1,int X2,int Y2, unsigned char const *grafika);

