#include "stm32f10x.h"
#include "grafiki.h"
#include "grafiki2.h"
#include "wspokr.h"

//Definicje uytkowe
#define wprzycisk1   (GPIOA->IDR & GPIO_Pin_9)
#define wprzycisk2   (GPIOA->IDR & GPIO_Pin_10)
#define wprzycisk3   (GPIOA->IDR & GPIO_Pin_11)
#define wprzycisk4   (GPIOA->IDR & GPIO_Pin_12)
#define outtsop      (GPIOA->IDR & GPIO_Pin_6)    //Do portu PA7 podlaczony odbiornik podczerwieni
#define iron         TIM2->CCR3=1000
#define iroff        TIM2->CCR3=0


#define wy1on       GPIOC->BSRR = GPIO_Pin_8    //Dioda sygnalizujaca dzilanie lampy
#define wy1off      GPIOC->BRR = GPIO_Pin_8
#define wy2on       GPIOC->BSRR = GPIO_Pin_9   //Buzer sygnalizujacy ukonczenie dzilania lampy
#define wy2off      GPIOC->BRR = GPIO_Pin_9


//--------------------------------------------
//Funkcje systemowe
void RCC_Config(void);
void GPIO_Config(void);
void NVIC_Config(void);
void TIM_Config(void);
//---------------------------------------------
//Funkcje obslugi pamieci flash
void Flash_odczyt(void);
void Flash_zapis(void);
//---------------------------------------------
//Funkcje uzytkowe
void changeorientation(void);
uint8_t pushbuttons(void);
void putbackground(u8 x, u8 y, u8 width, u8 height, unsigned char const *grafika);
void puttext(uint8_t selecttekst, uint16_t color);
void animebelt(uint8_t x, uint8_t y, uint8_t width, uint8_t height, uint16_t color, uint8_t *selectbelt, uint8_t numerbelt, uint8_t *firstuse);
void firstdrawmenu(uint8_t *firstdraw);
void mainbutton(void);
void buttons1(void);
void dectime(void);
void putactualtime(uint8_t x, uint8_t y, uint16_t *value, uint8_t *firstdraw);
void buttons2(void);
void changesettimes( uint8_t *channeltime, uint8_t *inkrementacja, uint8_t *dekrementacja);
void firstdrawmenu2(uint8_t *firstdraw2);
void putbelt(uint8_t x, uint8_t y, uint8_t *selecttime, uint8_t *chosetime, uint8_t numer, uint8_t *firstdraw);
void putvaluetime(uint8_t x, uint8_t y, uint8_t numer, uint8_t *firstdraw, uint8_t *selecttime, uint8_t *chosetime);
void timetodisplay(uint8_t x, uint8_t y, uint16_t wartosc, uint16_t color, uint16_t bkcolor, uint8_t alpha);
void buttons3(void);
void putpercentcircle(uint8_t *firstdraw, uint8_t power, uint16_t color);
void percentdisplay(uint8_t x, uint8_t y, uint16_t wartosc, uint16_t color, uint16_t bkcolor, uint8_t alpha);
void graphsoundonoff(uint8_t x, uint8_t y, uint8_t setting, uint8_t *firstdraw);
void buttons4(void);
void saveoptions(uint16_t color);
void controlir(void);


//--------------------------------------------
//Deklaracje zmiennych
volatile uint8_t flagabutton1, flagabutton2, flagabutton3, sterir, flagatsop;
volatile uint32_t TIMERUS, timeranime, timerbutton1, timerbutton2, timerbutton3, timerbelt, timersekund, czasinkrdekr, timercolor2, timerpower,
				  timersave1, timersave2, timerdzwiek, *wskustawien, tsoptime;
uint8_t bufforgrafiki[35000];
uint32_t bufforparam[3];
uint8_t Xanime=12, flagaX=0, rotatelcd=1, menu, varfirstdraw=1, recognizedbutton, selectmenu=1, firstbelt=1, firstdraw2=1, firstdraw3=1,
		chtime=1, seltime=0, inkr=0, dekr=0, flashzapisz=0, flagaIR=1;
uint16_t elmdrg2, wybranyczas;
int chosefont, rotate;
uint16_t ustawienia[7]={5, 10, 30, 60, 120, 50, 1};  //ustawione czasy-pierwsze 5 elementow, nastepnie moc lampy, oraz zalaczenie lub wylaczenie dzwieku

//-----------------------------------------------------------------------
//---------- Definicje obszarow flash uC---------------------------------
uint32_t EraseCounter = 0x00, Address = 0x00;
uint32_t NbrOfPage = 0x00;
volatile FLASH_Status FLASHStatus=FLASH_COMPLETE;

#define BaseAdresFlash 0x08000000

//ofsety osobno dla funkcji - dla zapamietywania wartosci kalibracyjnych touchapnelu
#define OffsetNazwy2 0x19000
#define BANK1_WRITE_START_ADDR2  ((uint32_t)0x08019000)  //Ustawienie 1kb
#define BANK1_WRITE_END_ADDR2    ((uint32_t)0x08019400)
#define FLASH_PAGE_SIZE         ((uint16_t)0x400)
//-------------------------------------------------------------------------



extern uint8_t OFFSETX, OFFSETY;

int main(void)
{
	RCC_Config();
	NVIC_Config();
    GPIO_Config();
    TIM_Config();


    //Inicjalizacja zegrar systemowego systick
    	if (SysTick_Config_Mod(SysTick_CLKSource_HCLK_Div8, 900)) //przerwanie co 0,1ms
    	{
    		while(1);		// W razie bledu petla nieskonczona
    	}

		//Inicjalizacja wyswietlacza
		LCDinit();

	    wskustawien=(uint32_t *)(BaseAdresFlash + OffsetNazwy2);  //ustawienie wskaznika na adres komorki ktora jest flaga - czy juz byla doknany zapis ustawien po pierwszym uruchomienu
	    if(*wskustawien!=0x256fabc4)
		{
	    	Flash_zapis();
	    }

	    Flash_odczyt();

	//----------------------------------------------------
	//Gwna ptla nieskoczonoci
	while(1)
	{

		//Menu glowne w programie
		while(!menu)
		{
			firstdrawmenu(&varfirstdraw);

			 animebelt(9, 3, 110, 18, Gray1, &selectmenu, 1, &firstbelt);  //animowane menu wyboru podmenu
			 animebelt(9, 29, 110, 18, Gray1, &selectmenu, 2, &firstbelt);  //animowane menu wyboru podmenu
			 animebelt(9, 54, 110, 18, Gray1, &selectmenu, 3, &firstbelt);  //animowane menu wyboru podmenu
			 animebelt(9, 79, 110, 18, Gray1, &selectmenu, 4, &firstbelt);  //animowane menu wyboru podmenu
			 animebelt(9, 104, 110, 18, Gray1, &selectmenu, 5, &firstbelt);  //animowane menu wyboru podmenu
			 mainbutton();
			 dectime();  //dekrementacja ustawionego czasu

			  controlir(); //kontrola diody IR

			changeorientation();  //procedura sprawdzajaca orientacje na wyswietlaczu
		}
		//Podmenu PRACA - podmenu w ktorym sa zalaczane i wylaczane LEDY UV w zaleznosci od ustawinia czasu
		while(menu==1)
		{

			putactualtime(2, 46, &wybranyczas, &varfirstdraw);

		    buttons1();  //obsluga przyciskow w podmenu 1
		    dectime();  //dekrementacja ustawionego czasu

		    controlir(); //kontrola diody IR

			changeorientation();  //procedura sprawdzajaca orientacje na wyswietlaczu
		}
		//Podemnu CZASY - podemnu w ktorym ustawiamy czasy dla poszczegolnych przyciskow
		while(menu==2)
		{
			firstdrawmenu2(&varfirstdraw);
			buttons2();

			changesettimes( &chtime, &inkr, &dekr);


			putbelt(72, 40,  &seltime, &chtime, 1, &firstdraw2);
			putbelt(72, 55,  &seltime, &chtime, 2, &firstdraw2);
			putbelt(72, 70,  &seltime, &chtime, 3, &firstdraw2);
			putbelt(72, 85,  &seltime, &chtime, 4, &firstdraw2);
			putbelt(72, 100,  &seltime, &chtime, 5, &firstdraw2);

			putvaluetime(82, 40, 1, &firstdraw3, &seltime, &chtime);
			putvaluetime(82, 55, 2, &firstdraw3, &seltime, &chtime);
			putvaluetime(82, 70, 3, &firstdraw3, &seltime, &chtime);
			putvaluetime(82, 85, 4, &firstdraw3, &seltime, &chtime);
			putvaluetime(82, 100, 5, &firstdraw3, &seltime, &chtime);

			dectime();  //dekrementacja ustawionego czasu

			 controlir(); //kontrola diody IR

			changeorientation();  //procedura sprawdzajaca orientacje na wyswietlaczu
		}
		//Podmenu MOC - podmenu w ktorym bedzie ustawiana moc swiecenia LED UV
		while(menu==3)
		{
			putpercentcircle(&varfirstdraw, ustawienia[5], Pink1);
			buttons3();

			dectime();  //dekrementacja ustawionego czasu

			 controlir(); //kontrola diody IR

			changeorientation();  //procedura sprawdzajaca orientacje na wyswietlaczu
		}
		//Podmenu DWIK - podmenu w ktorym zalaczamy lub wylaczamy dzwiek
		while(menu==4)
		{
			graphsoundonoff(32, 0, ustawienia[6], &varfirstdraw);
			buttons4();

			dectime();  //dekrementacja ustawionego czasu

			 controlir(); //kontrola diody IR

			changeorientation();  //procedura sprawdzajaca orientacje na wyswietlaczu
		}
		//Podmenu ZAPISZ - podmenu w ktorym zapisujemy ustawienia
		while(menu==5)
		{
			saveoptions(Red1);

			dectime();  //dekrementacja ustawionego czasu

			 controlir(); //kontrola diody IR

			changeorientation();  //procedura sprawdzajaca orientacje na wyswietlaczu
		}



	} //Koniec gwnej ptli nieskoczonej
} //Koniec gwnej funkcji


//-----------------------------------------------------------------------------------------------------------------------
//Funkcje systemowe
void GPIO_Config(void)
{
	//konfigurowanie portow GPIO
	  GPIO_InitTypeDef  GPIO_InitStructure;


      //Ustawienie Wejscie sterujace kontrolna dioda LED
      GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_9 | GPIO_Pin_10 | GPIO_Pin_11 | GPIO_Pin_12;
      GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IPU;
      GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
      GPIO_Init(GPIOA, &GPIO_InitStructure);

      //Port odpowiedzialny za odbiornik podczerwieni (automatyczne wlozenie reki do lampy UV)
      GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_6 ;
      GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN_FLOATING;
      GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
      GPIO_Init(GPIOA, &GPIO_InitStructure);

      //Wyjscie dla ukladu  odpowiedzialnego za jasnosc lamp - PWM
     GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0;
     GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
     GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP; //wyjscie alternatywne o wysokiej impedancji
     GPIO_Init(GPIOB, &GPIO_InitStructure);

     //Wyjscie dla ukladu PWM odpowiedzialnego za generowanie sygnalu dla nadajnika IR (dioda IR)
     GPIO_InitStructure.GPIO_Pin = GPIO_Pin_2;
     GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
     GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP; //wyjscie alternatywne o wysokiej impedancji
     GPIO_Init(GPIOA, &GPIO_InitStructure);


         GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_8 | GPIO_Pin_9;
   	    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
   	    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
   	    GPIO_Init(GPIOC, &GPIO_InitStructure);

       GPIOC->BRR = GPIO_Pin_8 | GPIO_Pin_9;

}

void RCC_Config(void)
//konfigurowanie sygnalow taktujacych
{
	  RCC_DeInit();                                          //Reset ustawien RCC
      RCC_HSEConfig(RCC_HSE_ON);                             //Wlaczenie HSE

	  RCC_HCLKConfig(RCC_SYSCLK_Div1);                     //ustaw HCLK=SYSCLK
	  RCC_PCLK2Config(RCC_HCLK_Div1);                      //ustaw PCLK2=HCLK
	  RCC_PCLK1Config(RCC_HCLK_Div1);                      //ustaw PCLK1=HCLK/2
	  RCC_PLLConfig(RCC_PLLSource_PREDIV1, RCC_PLLMul_9); //ustaw PLLCLK = HSE*9 czyli 8MHz * 9 = 72 MHz

	  RCC_PLLCmd(ENABLE);                                  //wlacz PLL
	  while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET){}  //odczekaj na poprawne uruchomienie PLL
	  RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);           //ustaw PLL jako zrodlo sygnalu zegarowego
	  while(RCC_GetSYSCLKSource() != 0x08){}                //odczekaj az PLL bedzie sygnalem zegarowym systemu

     /*Tu nalezy umiescic kod zwiazany z konfiguracja sygnalow zegarowych potrzebnych w programie peryferiow*/
        RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOC, ENABLE);//wlacz taktowanie portu GPIOC
		RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA, ENABLE);//wlacz taktowanie portu GPIOA
		RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB, ENABLE);//wlacz taktowanie portu GPIOB

		RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM3, ENABLE); //wlacz taktowanie TIM3
		RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM2, ENABLE); //wlacz taktowanie TIM2

}

void NVIC_Config(void)
{

	NVIC_InitTypeDef    NVIC_InitStructure;

	NVIC_InitStructure.NVIC_IRQChannel =SysTick_IRQn ; //tutaj trzeba zwrocic uwage na definicje w pliu stm32f10x.h
	//******************************************************************************************************************
  	NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0;
  	NVIC_InitStructure.NVIC_IRQChannelSubPriority = 1;
  	NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
  	NVIC_Init(&NVIC_InitStructure);

}

//Konfiguracja timera
void TIM_Config(void)
{
  //konfigurowanie licznikow

	//***************************************************************************************************
	//Poczatek konfiguracja timer3 odpowiedzialnego za jasnosc wyswietlacza
	//***************************************************************************************************

  TIM_TimeBaseInitTypeDef  TIM_TimeBaseStructure;
  TIM_OCInitTypeDef  TIM_OCInitStructure;

  // Konfiguracja TIM3
  // Ustawienia ukladu podstawy czasu
  TIM_TimeBaseStructure.TIM_Prescaler = 0;         //bez prescelera (prescaler=1)
  TIM_TimeBaseStructure.TIM_Period = 10000ul;      //czestotliwosc PWM =5,86kHz  poniewaz 72Mhz/8000=9kHz
  TIM_TimeBaseStructure.TIM_ClockDivision = TIM_CKD_DIV1;
  TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;

  TIM_TimeBaseInit(TIM3, &TIM_TimeBaseStructure);


  // Konfiguracja kanalu 3 - uzywamy kanalu 3 poniewaz jego wyjscie jest na GPIOB0
  TIM_OCInitStructure.TIM_OCMode = TIM_OCMode_PWM1; //tryb pwm
  TIM_OCInitStructure.TIM_OutputState = TIM_OutputState_Enable;
  TIM_OCInitStructure.TIM_Pulse = 0ul;          //poczatkowe wypelnienie maksymalne (TIMpulse/Timperiod)*100%=100%
  TIM_OCInitStructure.TIM_OCPolarity=TIM_OCPolarity_High;
  TIM_OC3Init(TIM3, &TIM_OCInitStructure);

  TIM_OC3PreloadConfig(TIM3, TIM_OCPreload_Enable);//wlaczenie buforowania

  TIM_ARRPreloadConfig(TIM3, ENABLE);//wlaczenie buforowania
  // Wlaczenie timera
  TIM_Cmd(TIM3, ENABLE);

  TIM3->CCR3=0; //w pierwszym momencie wylaczenie lampy


//Konfiguracja TIMER2 dla nadajnika IR
  // Ustawienia ukladu podstawy czasu
  TIM_TimeBaseStructure.TIM_Prescaler = 0;         //bez prescelera (prescaler=1)
  TIM_TimeBaseStructure.TIM_Period = 2000ul;      //czestotliwosc PWM =5,86kHz  poniewaz 72Mhz/2000=36kHz
  TIM_TimeBaseStructure.TIM_ClockDivision = TIM_CKD_DIV1;
  TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up;

  TIM_TimeBaseInit(TIM2, &TIM_TimeBaseStructure);


  // Konfiguracja kanalu 3 - uzywamy kanalu 3 poniewaz jego wyjscie jest na GPIOA2
  TIM_OCInitStructure.TIM_OCMode = TIM_OCMode_PWM1; //tryb pwm
  TIM_OCInitStructure.TIM_OutputState = TIM_OutputState_Enable;
  TIM_OCInitStructure.TIM_Pulse = 1000ul;          //poczatkowe wypelnienie maksymalne (TIMpulse/Timperiod)*100%=100%
  TIM_OCInitStructure.TIM_OCPolarity=TIM_OCPolarity_High;
  TIM_OC3Init(TIM2, &TIM_OCInitStructure);

  TIM_OC3PreloadConfig(TIM2, TIM_OCPreload_Enable);//wlaczenie buforowania

  TIM_ARRPreloadConfig(TIM2, ENABLE);//wlaczenie buforowania
  // Wlaczenie timera
  TIM_Cmd(TIM2, ENABLE);

  TIM2->CCR3=1000; //w pierwszym momencie ustawienie wypelnienia na 50%
}

//----------------------------------------------------------------------------------------------------------------------------------------
//Funkcje uzytkowe

//Funkcja zmieniajca orientacje na wyswietlaczu
void changeorientation(void)
{
	if(!wprzycisk4 && !elmdrg2)
			{
				elmdrg2=4000;

				rotatelcd++;
				if(rotatelcd>4) rotatelcd=1;

				ReadManyData(bufforgrafiki, bufforparam, 0, 0, 127, 127);   //zbuforowanie obszaru grafiki z calego wyswietlacza

				//MY, MX, MV
				switch(rotatelcd)
				{
				case 1:
				{
					OFFSETX=2;
					OFFSETY=3;
					MemoryControl(1, 1, 0, 0, 1, 0);  //ustawienie poczatku ukladu wspolrzednych dla wyswietlacza (lewy gorny rog, orag odczyt kolorow jako BGR)
					break;
				}
				case 2:
				{
					OFFSETX=3;
					OFFSETY=2;
					MemoryControl(1, 0, 1, 0, 1, 0);  //ustawienie poczatku ukladu wspolrzednych dla wyswietlacza (lewy gorny rog, orag odczyt kolorow jako BGR)
					break;
				}

				case 3:
				{
					OFFSETX=2;
					OFFSETY=1;
					MemoryControl(0, 0, 0, 0, 1, 0);  //ustawienie poczatku ukladu wspolrzednych dla wyswietlacza (lewy gorny rog, orag odczyt kolorow jako BGR)
					break;
				}
				case 4:
				{
					OFFSETX=1;
					OFFSETY=2;
					MemoryControl(0, 1, 1, 0, 1, 0);  //ustawienie poczatku ukladu wspolrzednych dla wyswietlacza (lewy gorny rog, orag odczyt kolorow jako BGR)
					break;
				}
				}

				//Wstawienie zbuforowanego obszaru grafiki
				putfrombufor(bufforgrafiki, bufforparam, 0, 0);

			}
			else if(wprzycisk4 && elmdrg2) elmdrg2--;
}


//Funkcja rysujaca napisy przy pierwszym wejsciu do podmenu
void firstdrawmenu(uint8_t *firstdraw)
{
	if(*firstdraw)
	{
		*firstdraw=0;

		putfastpicture(0, 0, 128, 128, wallpaper);  //wstawienie obrazka o wymiarze 128x128px poczatek w punkcie 0,0  grafika w tablicy(ostatni argument funkcji)
		chosefont=1;
	    tft_mputs( 19, 3, "PRACA", Black1, White, 1 );
	    tft_mputs( 19, 29, "CZASY",Black1, White, 1 );
	    tft_mputs( 37, 54, "MOC", Black1, White, 1 );
	    tft_mputs( 10, 79, "DWIK", Black1, White, 1 );
	    tft_mputs( 10, 104, "ZAPISZ", Black1, White, 1 );
	}
}


//Funkcja obslugi przycisku
uint8_t pushbuttons(void)
{
static uint8_t elmdrgpb1=0, elmdrgpb2=0, elmdrgpb3=0;

//obsluga przycisku 1
if(!wprzycisk1 && !elmdrgpb1)
{
	elmdrgpb1=200;
	flagabutton1=1;
}
	else if(wprzycisk1 && elmdrgpb1) elmdrgpb1--;
	else if(flagabutton1 && wprzycisk1 && !elmdrgpb1)
	{
		flagabutton1=0;    //wykasowanie flagi dla przycisku 1

		if(timerbutton1<20000)
		{
			timerbutton1=0;
			return 1;
		}
		else
		{
			timerbutton1=0;
			return 4;
		}
	}
//obsluga przycisku 2
if(!wprzycisk2 && !elmdrgpb2)
{
	elmdrgpb2=200;
	flagabutton2=1;
}
	else if(wprzycisk2 && elmdrgpb2) elmdrgpb2--;
	else if(flagabutton2 && wprzycisk2 && !elmdrgpb2)
	{
		flagabutton2=0;    //wykasowanie flagi dla przycisku 2

		if(timerbutton2<20000)
		{
			timerbutton2=0;
			return 2;
		}
		else
		{
			timerbutton2=0;
			return 5;
		}
	}
//obsluga przycisku 3
if(!wprzycisk3 && !elmdrgpb3)
{
	elmdrgpb3=200;
	flagabutton3=1;
}
	else if(wprzycisk3 && elmdrgpb3) elmdrgpb3--;
	else if(flagabutton3 && wprzycisk3 && !elmdrgpb3)
	{
		flagabutton3=0;    //wykasowanie flagi dla przycisku 3

		if(timerbutton3<20000)
		{
			timerbutton3=0;
			return 3;
		}
		else
		{
			timerbutton3=0;
			return 6;
		}
	}

return 0;
}

//Obsluga menu gownego
void mainbutton(void)
{
	recognizedbutton=pushbuttons();

	if(recognizedbutton)
	{
	switch(recognizedbutton)
	{
	case 1:
		menu=selectmenu;
		varfirstdraw=1;
		firstdraw2=1;
		firstdraw3=1;
		break;
	case 2:
	{
		selectmenu++;
		if(selectmenu>5) selectmenu=1;

		break;
	}
	case 3:
	{
        selectmenu--;
        if(!selectmenu) selectmenu=5;
		break;
	}
	case 4:
	{
		menu=selectmenu;
		varfirstdraw=1;
		break;
	}
	case 5:
	{
		selectmenu++;
		if(selectmenu>5) selectmenu=1;
		break;
	}
	case 6:
	{
		selectmenu--;
	    if(!selectmenu) selectmenu=5;
	    break;
	}
	}
	recognizedbutton=0;
	}
}

//Funkcja obslugi przyciskow w podmenu 1
//Obsluga podmenu
void buttons1(void)
{
	static uint8_t localflag=0;

	recognizedbutton=pushbuttons();

	if(recognizedbutton)
	{
	switch(recognizedbutton)
	{
	case 1:

        wybranyczas=ustawienia[0]+1;
		break;
	case 2:
	{
		wybranyczas=ustawienia[1]+1;
		break;
	}
	case 3:
	{
        wybranyczas=ustawienia[2]+1;
		break;
	}
	case 4: //ESC
	{
		menu=0;
		varfirstdraw=1;
		selectmenu++;
		if(selectmenu>5) selectmenu=1;
		break;
	}
	case 5:
	{
		wybranyczas=ustawienia[3]+1;
		break;
	}
	case 6:
	{
		wybranyczas=ustawienia[4]+1;
	    break;
	}
	}
	recognizedbutton=0;

	}

	if(ustawienia[0]==1) flagaIR=0; else flagaIR=1;

	if(flagaIR)
	{

		if(!wybranyczas)
		{
		if(outtsop)
		{
			flagatsop=1;

			if((tsoptime>1000) && localflag)
			{
				flagatsop=0;
				wybranyczas=ustawienia[0]+1;
				localflag=0;
			}
		}
		else if(!outtsop)
		{
			flagatsop=0;
			tsoptime=0;
			localflag=1;
		}
		}

	}
}


//--------------------------------------------------------------------------------------------------------------------
//Funkcja animujaca prostokat
void animebelt(uint8_t x, uint8_t y, uint8_t width, uint8_t height, uint16_t color, uint8_t *selectbelt, uint8_t numerbelt, uint8_t *firstuse)
{

static uint8_t aktualnystan[6];
static uint8_t liczbamenu=1;

	if(*firstuse)
	{		*firstuse=0;
		aktualnystan[0]=0;
		aktualnystan[1]=0;
		aktualnystan[2]=0;
		aktualnystan[3]=0;
		aktualnystan[4]=0;
		aktualnystan[5]=0;
		liczbamenu=1;
	}

	if(!timerbelt)
	{
		liczbamenu++;
		if(liczbamenu>6)
		{
		timerbelt=200;   //odstep pmiedzy zmianami animacji oraz sprawdzeniem
		liczbamenu=1;
		}

		if(*selectbelt!=numerbelt)
		{
			if(aktualnystan[numerbelt])
			{
		     putbackground(x+aktualnystan[numerbelt],  y, 2, height + 1, wallpaper);
			 aktualnystan[numerbelt]-=2;
			 if(!aktualnystan[numerbelt])
			 {
				 putbackground(x+aktualnystan[numerbelt],  y, 2, height+1, wallpaper);
			 }
			 else
			 puttext(numerbelt, Black1);
			}
		}
		else
		{
			if(aktualnystan[numerbelt]!=width)
			{
				full_rectalpha( x+aktualnystan[numerbelt], y, x+aktualnystan[numerbelt]+2, y+height, color);
				aktualnystan[numerbelt]+=2;
				if(aktualnystan[numerbelt]!=width) puttext(numerbelt, Black1); else puttext(numerbelt, White);

			}
		}

	}

}


//-----------------------------------------------------------------------------------------------------
//Funkcja piszaca napisy w menu glownym

void puttext(uint8_t selecttekst, uint16_t color)
{
	chosefont=1;
	switch(selecttekst)
	{
	    case 1:
	    tft_mputs( 19, 3, "PRACA", color, White, 1 );
	    break;
	    case 2:
	    tft_mputs( 19, 29, "CZASY", color, White, 1 );
	    break;
	    case 3:
	    tft_mputs( 37, 54, "MOC", color, White, 1 );
	    break;
            case 4:
	    tft_mputs( 10, 79, "DWIK", color, White, 1 );
	    break;
            case 5:
	    tft_mputs( 10, 104, "ZAPISZ", color, White, 1 );
	    break;
	}
}

//------------------------------------------------------------------------------------------------------
//Funkcja odpowiedzialna za odliczanie czasu
void dectime(void)
{
	static uint8_t dzwiek=0;

if(wybranyczas && !timersekund)
{
	wybranyczas--;

	if(wybranyczas)
	{
		timersekund=10000; //odmierzanie 1s
		//Lampa zalaczona lub wylaczona
		TIM3->CCR3=ustawienia[5]*100;
		wy1on;
		dzwiek=1;
	}
	else
	{
		TIM3->CCR3=0;
		wy1off;
	}
}

if(dzwiek && !wybranyczas && !timerdzwiek)
{
	timerdzwiek=10000; //dzwiek przez 1 sekunde
	dzwiek=0;
	if(ustawienia[6]) wy2on;
} else if(!dzwiek && !timerdzwiek)
{
	wy2off;
}

}

//-----------------------------------------------------------------------------------------------------
//Funkcja liczaca wartosc odmierzanego czasu
//Funkcja rysujace napis w polozeniu x=2 y=46, *value=wartosc timera, *firstdraw - flaga zezwalajaca na pierwsze narysowanie
void putactualtime(uint8_t x, uint8_t y, uint16_t *value, uint8_t *firstdraw)
{
static uint16_t actualtime=0xffff;
uint16_t tempcolor;
uint16_t  temp1, temp2, temp3;
char buforvalue[5];
const uint16_t selectcolor[6]={0x07E0, 0xAFE0, 0xF7E0, 0xFE20, 0xFB00, 0xF800};

	if((*value!=actualtime) || *firstdraw)
	{
	actualtime=*value;

	if(*firstdraw)
		{
		*firstdraw=0;
		putfastpicture(0, 0, 128, 128, wallpaper);  //wstawienie obrazka o wymiarze 128x128px poczatek w punkcie 0,0  grafika w tablicy(ostatni argument funkcji)
		}

	temp1=actualtime/100;
	temp2=actualtime-(100*temp1);
	temp2=temp2/10;
	temp3=actualtime-(100*temp1)-(10*temp2);

	buforvalue[0]=temp1+0x30;
	buforvalue[1]=temp2+0x30;
	buforvalue[2]=temp3+0x30;
	buforvalue[3]=0x73; //s
	buforvalue[4]=0x00; //znak konczasy null

	//ustawienie aktualnego koloru
	if(actualtime<6)
	{
	tempcolor=selectcolor[actualtime];
	}
	else
	{
	tempcolor=0xF800;
	}

	chosefont=5;
	putbackground(x-1,  y-1, 126, 36, wallpaper);
	tft_mputs( x, y, buforvalue, tempcolor, White, 1);
	}
}

//Funkcja obslugi przyciskow w podmenu 2
void buttons2(void)
{
static uint8_t licznik1=0, licznik2=0, flagap1=0, flagap2=0;
static uint32_t tryb1=5000, tryb2=5000;

recognizedbutton=pushbuttons();

	if(recognizedbutton)
	{
	switch(recognizedbutton)
	{
	case 1:
        	if(seltime)
		{
		 seltime=0;
	         tryb1=5000;  //Wyczyszczenie czasow
                 tryb2=5000;
		}
		else seltime=1;  //zaznaczenie czasu
		break;
	case 2:
	{
		if(!seltime)          //zmiana wyboru czasu
		{
		chtime++;
		if(chtime>5) chtime=1;
		}
		break;
	}
	case 3:
	{
        	if(!seltime)
		{
		chtime--;
		if(chtime==0) chtime=5;
		}
		break;
	}
	case 4: //ESC
	{
		menu=0;
		varfirstdraw=1;
		selectmenu++;
		if(selectmenu>5) selectmenu=1;
		break;
	}
	case 5:
	{
		if(!seltime)          //zmiana wyboru czasu
		{
		chtime++;
		if(chtime>5) chtime=1;
		}

		break;
	}
	case 6:
	{
	        if(!seltime)
		{
		chtime--;
		if(chtime==0) chtime=5;
		}
	    break;
	}
	}
	recognizedbutton=0;
	}

	if(seltime) //jezeli jestesmy w podmenu odpowiedzialnym za zmiane czasu
	{
		//zmiana predkosci inkrementacji oraz dekrementacji w zaleznosci od dlugosci trzymania przycisku
		if(!wprzycisk2 && !czasinkrdekr)
		{
			czasinkrdekr=tryb1;  //ustawienie 0,5s
			inkr=1;
			flagap1=1;

			licznik1++;
			if(licznik1>2)
			{
			   licznik1=0;
			   if(tryb1>200) tryb1-=800;
			}
		}
                else if(wprzycisk2 && !czasinkrdekr && flagap1)
		{
			 licznik1=0;
			 tryb1=5000;
		         flagap1=0;
		}

		if(!wprzycisk3 && !czasinkrdekr)
		{
			czasinkrdekr=tryb2;  //ustawienie 0,5s
			dekr=1;
			flagap2=1;

			licznik2++;
			if(licznik2>2)
			{
			   licznik2=0;
			   if(tryb2>200) tryb2-=800;
			}
		}
		else if(wprzycisk3 && !czasinkrdekr && flagap2)
		{
			licznik2=0;
			tryb2=5000;
			flagap2=0;
		}

	}
}

//Funkcja zmieniajaca ustawienia czasow
void changesettimes( uint8_t *channeltime, uint8_t *inkrementacja, uint8_t *dekrementacja)
{
	if(seltime)
	{
		if(*inkrementacja)
		{
                if(ustawienia[*channeltime-1]<1000) ustawienia[*channeltime-1]++;
		if(ustawienia[*channeltime-1]>999) ustawienia[*channeltime-1]=1;
		  *inkrementacja=0;
		}
		if(*dekrementacja)
		{
		 if(ustawienia[*channeltime-1]>0) ustawienia[*channeltime-1]--;
		 if(!ustawienia[*channeltime-1]) ustawienia[*channeltime-1]=999;
		  *dekrementacja=0;
		}
	}
}


//----------------------------------------------------------------------------------
void firstdrawmenu2(uint8_t *firstdraw2)
{
	if(*firstdraw2)
	{
		*firstdraw2=0;
		putfastpicture(0, 0, 128, 128, wallpaper);  //wstawienie obrazka o wymiarze 128x128px poczatek w punkcie 0,0  grafika w tablicy(ostatni argument funkcji)
		chosefont=6;
		tft_mputs( 22, 20, "SEKUNDY", Black1, White, 1);
		tft_mputs( 0, 40, "Czas1", Black1, White, 1 );
		tft_mputs( 0, 55, "Czas2", Black1, White, 1 );
		tft_mputs( 0, 70, "Czas3", Black1, White, 1 );
		tft_mputs( 0, 85, "Czas4", Black1, White, 1 );
		tft_mputs( 0, 100, "Czas5", Black1, White, 1 );
	}
}


//Funkcja rysujaca zmieniajace kolor strzalki w zaleznosci od tego czy wybralismy czas
void putbelt(uint8_t x, uint8_t y, uint8_t *selecttime, uint8_t *chosetime, uint8_t numer, uint8_t *firstdraw)
{
static uint8_t numerkoloru[6]={0,0,0,0,0,0};
static uint8_t flagakoloru[6]={1,1,1,1,1,1};
static uint8_t czaslokalny[6];
static uint8_t localflag[6];
const uint16_t colorbelt[7]={0x0000, 0x94B2, 0xAD55,  0xBDF7, 0xD6BA, 0xEF7D, 0xFFFF};

if(*firstdraw)
{
*firstdraw=0;

localflag[0]=1;
localflag[1]=1;
localflag[2]=1;
localflag[3]=1;
localflag[4]=1;
localflag[5]=1;

flagakoloru[0]=0;
flagakoloru[1]=0;
flagakoloru[2]=0;
flagakoloru[3]=0;
flagakoloru[4]=0;
flagakoloru[5]=0;

numerkoloru[0]=6;
numerkoloru[1]=6;
numerkoloru[2]=6;
numerkoloru[3]=6;
numerkoloru[4]=6;
numerkoloru[5]=6;
}
	if(numer==(*chosetime))
	{
		localflag[numer]=1;

		if(*selecttime)
		{

		//Animacja zmiany koloru strzalek
			if(czaslokalny[numer])
			{
				czaslokalny[numer]=0;

			     if(flagakoloru[numer]) numerkoloru[numer]+=1; else numerkoloru[numer]-=1;
			     if(numerkoloru[numer]>5) flagakoloru[numer]=0; else if(!numerkoloru[numer]) flagakoloru[numer]=1;

			     putmonograph(x, y+2, colorbelt[numerkoloru[numer]], Black1, 8, 8, stl, 1);
			     putmonograph(x+48, y+2, colorbelt[numerkoloru[numer]], Black1, 8, 8, stp, 1);

			}
		}
	     	else
	        {

			putmonograph(x, y+2, White, Black1, 8, 8, stl, 1);
			putmonograph(x+48, y+2, White, Black1, 8, 8, stp, 1);

	        }

	}
	else if(localflag[numer])
	{
		localflag[numer]=0; //wykasowanie flagi zezwalajacej na jednorazowe narysowanie

		putmonograph(x, y+2, Black1, Black1, 8, 8, stl, 1);
		putmonograph(x+48, y+2, Black1, Black1, 8, 8, stp, 1);
	}

	if (!timercolor2)
	    {
		timercolor2=500;
		czaslokalny[0]=1;
		czaslokalny[1]=1;
		czaslokalny[2]=1;
		czaslokalny[3]=1;
		czaslokalny[4]=1;
		czaslokalny[5]=1;
		}
}


//funkcja rysujaca wartosci funkcji
void putvaluetime(uint8_t x, uint8_t y, uint8_t numer, uint8_t *firstdraw, uint8_t *selecttime, uint8_t *chosetime)
{
static uint16_t temptime[5];
static uint8_t actualnumber[5];
uint8_t flagapomocnicza=0;
static uint8_t ss=0;

	if(*firstdraw)
	{
	*firstdraw=0;
	temptime[0]=0x8000;
	temptime[1]=0x8000;
	temptime[2]=0x8000;
	temptime[3]=0x8000;
	temptime[4]=0x8000;

	actualnumber[0]=0xff;
	actualnumber[1]=0xff;
	actualnumber[2]=0xff;
	actualnumber[3]=0xff;
	actualnumber[4]=0xff;

	ss=*selecttime;
	}

	chosefont=6;

		if(ustawienia[numer-1]!=temptime[numer-1])
		{
			temptime[numer-1]=ustawienia[numer-1];
			flagapomocnicza=1;
		}
		if(*chosetime==numer)
		{
			if(ss!=*selecttime)
			{
				ss=*selecttime;
				flagapomocnicza=1;
			}
		}
		if((actualnumber[numer-1]!=*chosetime) || flagapomocnicza)
		{
			actualnumber[numer-1]=*chosetime;
			if(flagapomocnicza) flagapomocnicza=0;

			if(*chosetime==numer)
			{
				if(*selecttime)
				{
					timetodisplay(x, y, temptime[numer-1], White, Black1, 0);
				}
				else
				{
					timetodisplay(x, y, temptime[numer-1], Black1, White, 0);
				}
			}
			else
			{
				putbackground(x, y, 37, 15, wallpaper);
				timetodisplay(x, y, temptime[numer-1], Black1, Red1, 1);
			}
		}

}

//funkcja wpisujaca aktualne wartosci czasow
void timetodisplay(uint8_t x, uint8_t y, uint16_t wartosc, uint16_t color, uint16_t bkcolor, uint8_t alpha)
{
 char buforvalue[4];

buforvalue[0]=wartosc/100;
buforvalue[1]=wartosc-buforvalue[0]*100;
buforvalue[1]=buforvalue[1]/10;
buforvalue[2]=wartosc%10;

buforvalue[0]+=0x30;
buforvalue[1]+=0x30;
buforvalue[2]+=0x30;
buforvalue[3]=0x00; //null

		tft_mputs( x, y, buforvalue, color, bkcolor, alpha);
}


//Funkcja obslugi przyciskow dla podmenu 3
void buttons3(void)
{
	recognizedbutton=pushbuttons();

	if(recognizedbutton)
	{
	switch(recognizedbutton)
	{
	case 4: //ESC
	{
		menu=0;
		varfirstdraw=1;
		selectmenu++;
		if(selectmenu>5) selectmenu=1;
		break;
	}
	}
	recognizedbutton=0;
	}
	if(!wprzycisk2 && !timerpower)
	{
		timerpower=200;
		ustawienia[5]++;
		if(ustawienia[5]>100) ustawienia[5]=100;  //zwiekszenie mocy lampy
	}
	if(!wprzycisk3 && !timerpower)
	{
		timerpower=200;
		if(ustawienia[5]) ustawienia[5]--;   //zmniejszenie mocy lampy
	}
}

//Funkcja rysujaca wykres okragly w zaleznosci od mocy
void putpercentcircle(uint8_t *firstdraw, uint8_t power, uint16_t color)
{
	uint16_t i;
    static uint8_t temppower=0;
    uint16_t pomoc1;
     static uint16_t k=0;

	if(*firstdraw)
	{
		*firstdraw=0;
		putfastpicture(0, 0, 128, 128, wallpaper);  //wstawienie obrazka o wymiarze 128x128px poczatek w punkcie 0,0  grafika w tablicy(ostatni argument funkcji)

		pomoc1=(power*360)/100;

		for(i=0; i<pomoc1; i++)
		{
		   tft_linebold(64, 64,wsplokrx[i],wsplokry[i],color);
		   k=i;
		}
		percentdisplay(28, 55, ustawienia[5], White, Black1, 0);

	}

	if(temppower!=power)
	{

		if(power>temppower)
		{
			temppower=power;
			pomoc1=(temppower*360)/100;
			for(i=k; i<pomoc1; i++) tft_linebold(64, 64,wsplokrx[i],wsplokry[i],color);
			k=i;
			percentdisplay(28, 55, ustawienia[5], White, Black1, 0);
		}
		else
		{
			temppower=power;
			pomoc1=(temppower*360)/100;
			for(i=k; i>pomoc1; i--) tft_linewallpaper(64, 64, wsplokrx[i], wsplokry[i], wallpaper);
			k=i;
			percentdisplay(28, 55, ustawienia[5], White, Black1, 0);
		}
	}
}

//Funkcja wstawiajaca wartosc w procentach
void percentdisplay(uint8_t x, uint8_t y, uint16_t wartosc, uint16_t color, uint16_t bkcolor, uint8_t alpha)  //y=48  x=2
{
 char buforvalue[5];

 chosefont=1;  //18px wide  18px height

buforvalue[0]=wartosc/100;
buforvalue[1]=wartosc-buforvalue[0]*100;
buforvalue[1]=buforvalue[1]/10;
buforvalue[2]=wartosc%10;

buforvalue[0]+=0x30;
buforvalue[1]+=0x30;
buforvalue[2]+=0x30;
buforvalue[3]=0x25; //%
buforvalue[4]=0x00;

		tft_mputs( x, y, buforvalue, color, bkcolor, alpha);
}

//Funkcja, ktora wyswietla czy mamy zalaczony czy wylaczony dzwiek
void graphsoundonoff(uint8_t x, uint8_t y, uint8_t setting, uint8_t *firstdraw)
{
	static uint16_t tempsetting=0xff;

	if(*firstdraw)
	{
		*firstdraw=0;

		tempsetting=0xff;

		putfastpicture(0, 0, 128, 128, wallpaper);

		chosefont=6;
		tft_mputs( x-16, y+74, "Zaczy", Black1, White, 1);
		tft_mputs( x-10, y+87, "dwik?", Black1, White, 1);

	}

	//Zmiana rysunku monochromatycznego
	if(tempsetting!=setting)
	{
		tempsetting=setting;

		if(tempsetting)
		{
			putbackground(x-1, y+6, 66, 66, wallpaper);
			putmonograph(x, y+7, Green1, White, 64, 64, soundon, 1);

			putbackground(x-17, y+104, 38, 15, wallpaper);
			tft_mputs( x-16, y+105, "TAK", White, Black1, 0);
			putbackground(x+44, y+104, 38, 15, wallpaper);
			tft_mputs( x+44, y+105, "NIE", Black1, White, 1);
		}
		else
		{
			putbackground(x-1, y+6, 66, 66, wallpaper);
			putmonograph(x, y+7, Red1, White, 64, 64, soundoff, 1);

			putbackground(x-17, y+104, 38, 15, wallpaper);
			tft_mputs( x-16, y+105, "TAK", Black1, White, 1);
			putbackground(x+44, y+104, 38, 15, wallpaper);
			tft_mputs( x+44, y+105, "NIE", White, Black1, 0);
		}
	}
}

//Obsluga podmenu nr 4 - odpowiedzialnego za zmiane ustawien dzwieku
void buttons4(void)
{

	recognizedbutton=pushbuttons();

	if(recognizedbutton)
	{
	switch(recognizedbutton)
	{
	case 1:

		break;
	case 2:
	{
		if(ustawienia[6]) ustawienia[6]=0; else ustawienia[6]=1;
		break;
	}
	case 3:
	{
		if(ustawienia[6]) ustawienia[6]=0; else ustawienia[6]=1;
		break;
	}
	case 4: //ESC
	{
		menu=0;
		varfirstdraw=1;
		selectmenu++;
		if(selectmenu>5) selectmenu=1;
		break;
	}
	case 5:
	{
		if(ustawienia[6]) ustawienia[6]=0; else ustawienia[6]=1;
		break;
	}
	case 6:
	{
		if(ustawienia[6]) ustawienia[6]=0; else ustawienia[6]=1;
	    break;
	}
	}
	recognizedbutton=0;
	}
}

//Funkcja w ktorej nastepuje zapisywanie ustawien
void saveoptions(uint16_t color)
{
	uint16_t flaga=1, numer=1;


	timersave1=40000; //4s animacji
	timersave2=0;

	putfastpicture(0, 0, 128, 128, wallpaper);

	while(timersave1)
	{
		if(!timersave2)
		{
			timersave2=1000;
			if(flaga) numer++; else numer--;
			if(numer>5) flaga=0; else if(numer==1) flaga=1;

			putbackground(39, 34, 55, 32, wallpaper);
			switch(numer)
			{
			case 1:
				putmonograph(17, 17, 0x0000, White, 96, 96, save1, 1);
				break;
			case 2:
				putmonograph(17, 17, 0x0000, White, 96, 96, save2, 1);
				break;
			case 3:
				putmonograph(17, 17, 0x0000, White, 96, 96, save3, 1);
				break;
			case 4:
				putmonograph(17, 17, 0x0000, White, 96, 96, save4, 1);
				break;
			case 5:
				putmonograph(17, 17, 0x0000, White, 96, 96, save5, 1);
				break;
			case 6:
				putmonograph(17, 17, 0x0000, White, 96, 96, save6, 1);
				break;
			}

		}
	}

	//Wyjscie do podmenu glownego
	menu=0;
	varfirstdraw=1;
	selectmenu++;
	if(selectmenu>5) selectmenu=1;

	//W tym miejscu nastepuje zapis wszystkich ustawie
	//----------------------------------------------------------------------
	flashzapisz=1;
	Flash_zapis();
	flashzapisz=0;
	//----------------------------------------------------------------------
}

//Funkcja obslugi diody IR
void controlir(void)
{
static uint8_t flagatemp=1;

	if(!sterir)
	{

		if(flagatemp)
		{
			flagatemp=0;
			iron;
			sterir=20;
		}
		else
		{
			flagatemp=1;
			iroff;
			sterir=40;
		}
	}
}

//--------------------------------------------------------------------------
//Funkcje obslugi pamieci flash
//--------------------------------------------------------------------------

//Funkcja odczytujaca wspolczynniki dla kalibracji touchpanelu
void Flash_odczyt(void)
{
	uint32_t *p;
	uint32_t  t;

	p=(uint32_t *)(BaseAdresFlash+OffsetNazwy2+4);

	for(t=0; t<=6; t++)
	{
	 ustawienia[t]=(uint16_t)*p; //przepisanie wartosci z flash
	  p++;
	}

}

// Wersje drugie dla wspolczynnikow kalibracji panelu oraz kalibracji pomiaru
void Flash_zapis(void)
{
	 uint32_t   i;
     volatile uint32_t  j;
     uint32_t *k;





 	k=(uint32_t *)(BaseAdresFlash + OffsetNazwy2);  //ustawienie wskaznika na adres komorki ktora jest flaga czy juz byl dokonany zapis i pierwsze uruchonmienie

 	if((*k!=0x256fabc4) || flashzapisz) //sprawdzenie po zalaczeniu czy pamiec juz byla uzywana i nie jest to pierwszy raz po zapisie
 	{

	//Odblokowanie flash

	FLASH_Unlock();

	NbrOfPage = (BANK1_WRITE_END_ADDR2 - BANK1_WRITE_START_ADDR2) / FLASH_PAGE_SIZE;

	FLASH_ClearFlag(FLASH_FLAG_EOP|FLASH_FLAG_PGERR|FLASH_FLAG_WRPRTERR);




  // Wykasowanie pamieci
  for(EraseCounter = 0; (EraseCounter < NbrOfPage) && (FLASHStatus == FLASH_COMPLETE); EraseCounter++)
  {
    FLASHStatus = FLASH_ErasePage(BANK1_WRITE_START_ADDR2 + (FLASH_PAGE_SIZE * EraseCounter));
  }


		while(FLASH_COMPLETE!=FLASH_ProgramWord(BaseAdresFlash + OffsetNazwy2, 0x256fabc4))   //zmienna blokujaca nadpisanie przy uruchomieniu
			{
			}

		j=(BaseAdresFlash+OffsetNazwy2+4);


		//W tym miejscu nastepuje wpisanie zmiennych kalibracyjnych touchpanelu

		for(i=0; i<=6; i++)
		{
			 while(FLASH_COMPLETE!=FLASH_ProgramWord(j, (uint32_t)ustawienia[i]))
			 {
			 }
			 j=j+4;

	    }

	FLASH_Lock();  //zablokowanie dostepu do pamieci flash

 	}
}


